@@ -21,6 +21,9 @@ identify <- function(x){
   } else if (x@model == "tsdlvm1"){
     x <- identify_tsdlvm1(x)
     return(x)
+  } else if (x@model == "Ising"){
+    x <- identify_Ising(x)
+    return(x)
   }
   
   
