@@ -139,6 +139,9 @@ stepup <- function(
         matrices <- c(matrices,"omega_epsilon")
       }
       
+    }  else if (x@model == "Ising"){
+      matrices <- c("omega")
+     
     }  else stop("No default argument for 'matrices' for current model.")
   }
   
